
clear all
cd "/Volumes/GoogleDrive/My Drive/active/ietfcollab/RP.final"


* DRAFT LEVEL DATA
insheet using "drafts.csv"
gen time_period = date(date2,"DMY")
format time_period %td



/*

* TABLE 1
sum published versions duration auth_remote auth_dorg auth_us auth_prior ///
	org_presence prior_pubs lnfilesize key_count key_novelty combo_novelty ///
	simul_drafts auth_n wg_submission
corr published versions duration auth_remote auth_dorg auth_us auth_prior ///
	org_presence prior_pubs lnfilesize key_count key_novelty combo_novelty ///
	simul_drafts auth_n wg_submission


* TABLE 2
* model 1	
qui logit published auth_remote auth_dorg auth_us auth_prior ///
	org_presence prior_pubs lnfilesize key_count key_novelty combo_novelty ///
	simul_drafts wg_submission i.auth_n i.time_period, r
est store PUB1
* margins for effect sizes
margins , at(auth_remote = (0 1) )
margins , at(auth_dorg = (0 1) )	
* model 2
qui poisson versions published auth_remote auth_dorg ///
	auth_us auth_prior ///
	org_presence prior_pubs lnfilesize key_count key_novelty combo_novelty ///
	simul_drafts wg_submission i.auth_n i.time_period, r
est store VER1
* model 3
qui poisson versions c.auth_remote##i.published c.auth_dorg##i.published  ///
	auth_us auth_prior ///
	org_presence prior_pubs lnfilesize key_count key_novelty combo_novelty ///
	simul_drafts wg_submission i.auth_n i.time_period, r
est store VER2
* model 4
qui reg duration published auth_remote auth_dorg ///
	auth_us auth_prior ///
	org_presence prior_pubs lnfilesize key_count key_novelty combo_novelty ///
	simul_drafts wg_submission i.auth_n i.time_period, r
est store DUR1
* model 5
qui reg duration c.auth_remote##i.published c.auth_dorg##i.published  ///
	auth_us auth_prior ///
	org_presence prior_pubs lnfilesize key_count key_novelty combo_novelty ///
	simul_drafts wg_submission i.auth_n i.time_period, r
est store DUR2
* table
esttab PUB1 VER1 VER2 DUR1  DUR2 , drop(*.auth_n *.time_period) ///
	starlevels(+ 0.10 * 0.05 ** 0.01) nobaselevels r2 pr2 b(3)

	
* fig 7 and marginal effects
* model 3
qui poisson versions c.auth_remote##i.published c.auth_dorg##i.published  ///
	auth_us auth_prior ///
	org_presence prior_pubs lnfilesize key_count key_novelty combo_novelty ///
	simul_drafts wg_submission i.auth_n i.time_period, r
margins , at(auth_dorg = (0 1) published = (0  1))
margins , at(auth_remote = (0 1) published = (0  1))
qui margins , at(auth_dorg = (0(.1)1) published = (0  1))
marginsplot, ytitle("Project Versions") xtitle("Auth Diff Org Index") title("") ///
	legend( rows(1) title("") order(3 "Not Published" 4 "Published" )) ///
	plot1opts(msymbol(S T))
graph save f1a, replace
qui margins , at(auth_remote = (0(.1)1) published = (0  1))
marginsplot, ytitle("Project Versions") xtitle("Auth Remote Index")  title("") ///
	legend( rows(1) title("") order(3 "Not Published" 4 "Published" )) ///
	plot1opts(msymbol(S T))
graph save f1b, replace		
* model 5
qui reg duration c.auth_remote##i.published c.auth_dorg##i.published  ///
	auth_us auth_prior ///
	org_presence prior_pubs lnfilesize key_count key_novelty combo_novelty ///
	simul_drafts wg_submission i.auth_n i.time_period, r
margins , at(auth_dorg = (0 1) published = (0  1))
margins , at(auth_remote = (0 1) published = (0  1))
qui margins , at(auth_dorg = (0(.1)1) published = (0  1))
marginsplot, ytitle("Duration in Days") xtitle("Auth Diff Org Index")  title("") ///
	legend( rows(1) title("")order(3 "Not Published" 4 "Published" )) ///
	plot1opts(msymbol(S T))
graph save f2a, replace
qui margins , at(auth_remote = (0(.1)1) published = (0  1))
marginsplot, ytitle("Duration in Days") xtitle("Auth Remote Index")  title("") ///
	legend( rows(1) title("") order(3 "Not Published" 4 "Published" )) ///
	plot1opts(msymbol(S T))
graph save f2b, replace
graph combine f1a.gph f1b.gph f2a.gph f2b.gph
erase f1a.gph
erase f1b.gph
erase f2a.gph
erase f2b.gph	
exit	


*/



* DRAFT/VERSION LEVEL DATA
clear all
insheet using "drafts_versions.csv"
recode duration (.=180)
* turn diversity measures into binaries
gen d_auth_dorg =  (auth_dorg>0)
gen d_auth_remote =  (auth_remote>0)
* abandoned
gen abandoned = (version == versions )
* drop versions 7+
drop if version > 6


* FIGURE 8
binsreg filesize version ,  by(d_auth_dorg) ci(3,3) ///
	legend(order(1 "Single Org" 3 "Multiple Orgs")) ///
	ytitle("Filesize") xtitle("Version Number") ///
	title("Organizational Boundaries")
graph save t1, replace
binsreg filesize version ,  by(d_auth_remote) ci(3,3) ///
	legend(order(1 "Co-located" 3 "Distant")) ///
	ytitle("Filesize") xtitle("Version Number") ///
	title("Geographic Proximity")
graph save t2, replace
graph combine t1.gph t2.gph, col(2) title("File Sizes by Version Number")


* FIGURE 9
binsreg duration version,  by(d_auth_dorg) ci(3,3) ///
	legend(order(1 "Single Org" 3 "Multiple Orgs")) ///
	ytitle("Days to Next Revision") xtitle("Version Number") ///
	title("Organizational Boundaries")
graph save t1, replace
binsreg duration version ,  by(d_auth_remote) ci(3,3) ///
	legend(order(1 "Co-located" 3 "Distant"))  ///
	ytitle("Days to Next Revision") xtitle("Version Number") ///
	title("Geographic Proximity")
graph save t2, replace
graph combine t1.gph t2.gph, col(2) title("Work Duration by Version Number")

* FIGURE 10
binsreg abandoned version,  by(d_auth_dorg) ci(3,3) ///
	legend(order(1 "Single Org" 3 "Multiple Orgs")) ///
	ytitle("Final Version") xtitle("Version Number") ///
	title("Organizational Boundaries")
graph save t1, replace
binsreg abandoned version ,  by(d_auth_remote) ci(3,3) ///
	legend(order(1 "Co-located" 3 "Distant")) ///
	ytitle("Final Version") xtitle("Version Number") ///
	title("Geographic Proximity")
graph save t2, replace
graph combine t1.gph t2.gph, col(2) title("Draft Abandonment by Version Number")

erase t1.gph
erase t2.gph



